@@ -1,10 +1,11 @@
-use clap::{AppSettings, Clap};
+use crate::consts::package::VERSION;
+use clap::{AppSettings, Parser};
 
-#[derive(Clap)]
+#[derive(Parser)]
 #[clap(
     name = "bovine",
+    version = VERSION,
     about = "Manager for single node Rancher clusters: https://github.com/nickgerace/bovine",
-    global_setting = AppSettings::ColorNever,
     global_setting = AppSettings::DisableVersionFlag,
 )]
 pub struct Opt {
@@ -20,8 +21,13 @@ pub struct Opt {
     pub subcmd: SubCommand,
 }
 
-#[derive(Clap)]
+#[derive(Parser)]
 pub enum SubCommand {
+    #[clap(
+        name = "bootstrap-password",
+        about = "Find and display the bootstrap password (Rancher >=v2.6)"
+    )]
+    BootstrapPW(BootstrapPW),
     #[clap(
         name = "get",
         about = "Get and display information for a given Rancher container (JSON)"
@@ -58,13 +64,29 @@ pub enum SubCommand {
     Version(Version),
 }
 
-#[derive(Clap, Debug)]
+#[derive(Parser, Debug)]
+pub struct BootstrapPW {
+    #[clap(
+        about = "ID of the Rancher container running or not-running (if empty, it will select a Rancher container at random, which is useful when only one container is running)"
+    )]
+    pub container_id: Option<String>,
+    #[clap(
+        long,
+        short,
+        about = "Display the entire log line where the bootstrap password was found"
+    )]
+    pub verbose: bool,
+    #[clap(long, short, about = "Wait for the bootstrap password log to appear")]
+    pub wait: bool,
+}
+
+#[derive(Parser, Debug)]
 pub struct Get {
     #[clap(about = "ID of the Rancher container running")]
     pub container_id: String,
 }
 
-#[derive(Clap, Debug)]
+#[derive(Parser, Debug)]
 pub struct List {
     #[clap(long, short, about = "Show only containing that are running")]
     pub running: bool,
@@ -72,7 +94,7 @@ pub struct List {
     pub short: bool,
 }
 
-#[derive(Clap, Debug)]
+#[derive(Parser, Debug)]
 pub struct Logs {
     #[clap(
         about = "ID of the Rancher container running or not-running (if empty, it will select a Rancher container at random, which is useful when only one container is running)"
@@ -80,36 +102,15 @@ pub struct Logs {
     pub container_id: Option<String>,
     #[clap(long, short, about = "Follow logs")]
     pub follow: bool,
-    #[clap(
-        long,
-        short = 'p',
-        visible_aliases = &["password", "pw"],
-        about = "Attempt to find the bootstrap password (>=v2.6) (caution: finding the bootstrap password relies on parsing Rancher logs and is not an API call)"
-    )]
-    pub find_bootstrap_password: bool,
-    #[clap(
-        long,
-        short,
-        requires = "find-bootstrap-password",
-        about = "Display the entire log line where the bootstrap password was found"
-    )]
-    pub verbose: bool,
-    #[clap(
-        long,
-        short,
-        requires = "find-bootstrap-password",
-        about = "Wait for the bootstrap password log to appear"
-    )]
-    pub wait: bool,
 }
 
-#[derive(Clap, Debug)]
+#[derive(Parser, Debug)]
 pub struct Restart {
     #[clap(about = "ID of the Rancher container running")]
     pub container_id: String,
 }
 
-#[derive(Clap, Debug)]
+#[derive(Parser, Debug)]
 pub struct Run {
     #[clap(long, about = "Display the Docker API container config (JSON)")]
     pub dry_run: bool,
@@ -131,7 +132,7 @@ pub struct Run {
     pub common: LaunchFlags,
 }
 
-#[derive(Clap, Debug)]
+#[derive(Parser, Debug)]
 pub struct Stop {
     #[clap(
         long,
@@ -151,7 +152,7 @@ pub struct Stop {
     pub dry_run: bool,
 }
 
-#[derive(Clap, Debug)]
+#[derive(Parser, Debug)]
 pub struct Upgrade {
     #[clap(about = "ID of the Rancher container running")]
     pub container_id: String,
@@ -167,14 +168,14 @@ pub struct Upgrade {
     pub common: LaunchFlags,
 }
 
-#[derive(Clap, Debug)]
+#[derive(Parser, Debug)]
 pub struct Version {
     #[clap(long, short, about = "Display only the version tag")]
     pub short: bool,
 }
 
 // Subcommands using these flags should likely be "boxed": https://rust-lang.github.io/rust-clippy/master/index.html#large_enum_variant
-#[derive(Clap, Debug)]
+#[derive(Parser, Debug)]
 pub struct LaunchFlags {
     #[clap(
         long,
